@@ -1,8 +1,14 @@
 package Net::Google::Code::Issue;
 use Moose;
 use Params::Validate qw(:all);
-with 'Net::Google::Code::Role';
+with 'Net::Google::Code::Role::Fetchable', 'Net::Google::Code::Role::URL';
 use Net::Google::Code::Issue::Comment;
+use Net::Google::Code::Issue::Attachment;
+
+has 'project' => (
+    isa      => 'Str',
+    is       => 'rw',
+);
 
 has 'state' => (
     isa     => 'HashRef',
@@ -37,11 +43,12 @@ for my $prop (@PROPS) {
 
 sub load {
     my $self = shift;
-    my ($id) = validate_pos( @_, { type => SCALAR } );
-    $self->state->{id} = $id;
+    my $id = shift || $self->id;
+    die "current object doesn't have id and load() is not passed an id either"
+      unless $id;
     my $content = $self->fetch( $self->base_url . "issues/detail?id=" . $id );
-    $self->parse($content);
-    return $id;
+    $self->state->{id} = $id;
+    return $self->parse($content);
 }
 
 sub parse {
@@ -68,23 +75,9 @@ sub parse {
     $text =~ s/\r\n/\n/g;
     $self->state->{description} = $text;
 
-    my $att_tags = $tree->look_down( class => 'attachments' );
-    my @attachments;
-    for my $tag ($att_tags) {
-        my @items = $att_tags->find_by_tag_name('tr');
-        require Net::Google::Code::Issue::Attachment;
-        while ( scalar @items ) {
-            my $tr1 = shift @items;
-            my $tr2 = shift @items;
-            my $a =
-              Net::Google::Code::Issue::Attachment->new(
-                project => $self->project );
-
-            if ( $a->parse( [ $tr1, $tr2 ] ) ) {
-                push @attachments, $a;
-            }
-        }
-    }
+    my $att_tag = $tree->look_down( class => 'attachments' );
+    my @attachments =
+      Net::Google::Code::Issue::Attachment::parse_attachments($att_tag);
     $self->attachments( \@attachments );
 
     my ($meta) = $tree->look_down( id => 'issuemeta' );
@@ -163,6 +156,8 @@ Net::Google::Code::Issue - Google Code Issue
 
 =item parse
 
+=item project
+
 =item id
 
 =item status
