@@ -2,7 +2,12 @@ package Net::Google::Code::Wiki;
 
 use Moose;
 use Params::Validate qw(:all);
-with 'Net::Google::Code::Role';
+with 'Net::Google::Code::Role::Fetchable', 'Net::Google::Code::Role::URL';
+
+has 'project' => (
+    isa      => 'Str',
+    is       => 'rw',
+);
 
 has 'name' => (
     isa => 'Str',
@@ -46,6 +51,7 @@ has 'comments' => (
 
 sub load_source {
     my $self = shift;
+    die "current object doesn't have name" unless $self->name;
     my $source =
       $self->fetch( $self->base_svn_url . 'wiki/' . $self->name . '.wiki' );
     $self->source($source);
@@ -70,6 +76,8 @@ sub parse_source {
 sub load {
     my $self = shift;
     my $name = shift || $self->name;
+    die "current object doesn't have name and load() is not passed a name either"
+      unless $name;
 
     # http://code.google.com/p/net-google-code/wiki/TestPage
     my $content = $self->fetch( $self->base_url . 'wiki/' . $name );
@@ -141,6 +149,8 @@ Net::Google::Code::Wiki - Google Code Wiki
 
 =item parse_source
 
+=item project
+
 =item name
 
 =item source
